==> office-ui-fabric-react-0.1.2.tgz: package/src/components/List/React.List.js <==
/*
 * src/components/List/React.List.js
 */

'use strict';

var React = require('react');

var Components = {
    base: require('../React.Component')
};

var Attributes = Components.base.Attributes.div;

var Arrays = {
    kind: ['grid']
};

var List = React.createClass({

    displayName: 'List',

    mixins: [Components.base],

    childContextTypes: {

        // Event handler content attribute
        onClick: React.PropTypes.func // (eventKey,event)
    },

    getChildContext: function() {
        return {
            onClick: this.handleSelect
        };
    },

    propTypes: Object.assign({}, Attributes, {

        // Event handler content attribute
        onSelect: React.PropTypes.func, // (eventKey,selected,event)

        // Office-UI attribute
        eventKey: React.PropTypes.any,
        kind: React.PropTypes.oneOf(Arrays.kind)
    }),

    render: function() {
        return (
            React.DOM.div(
                this.getProps(Attributes, this.props, {
                    className: getClassName(this, this.props)
                }),
                getItems(this, this.props)
            )
        );
    },

    handleSelect: function(eventKey, event) {
        this.handle(this, 'onSelect', [this.props.eventKey, eventKey, event]);
    }

});

function getClassName(that, props) {
    var includes = that.includes(props, Arrays, 'ms-List--');
    return that.className(props.className, 'ms-List', includes);
}

function getItems(that, props) {
    return React.Children.map(props.children, function(e, i) {
        return React.cloneElement(e, {eventKey: i});
    });
}

module.exports = List;

==> office-ui-fabric-react-0.1.3.tgz: package/src/components/List/React.List.js <==
/*
 * src/components/List/React.List.js
 */

'use strict';

var React = require('react');

var Components = {
    base: require('../React.Component')
};

var Attributes = Components.base.Attributes.ul;

var Arrays = {
    kind: ['grid']
};

var List = React.createClass({

    displayName: 'List',

    mixins: [Components.base],

    childContextTypes: {

        // Event handler content attribute
        onClick: React.PropTypes.func // (eventKey,event)
    },

    getChildContext: function() {
        return {
            onClick: this.handleSelect
        };
    },

    propTypes: Object.assign({}, Attributes, {

        // Event handler content attribute
        onSelect: React.PropTypes.func, // (eventKey,selected,event)

        // Office-UI attribute
        eventKey: React.PropTypes.any,
        kind: React.PropTypes.oneOf(Arrays.kind)
    }),

    render: function() {
        return (
            React.DOM.ul(
                this.getProps(Attributes, this.props, {
                    className: getClassName(this, this.props)
                }),
                getItems(this, this.props)
            )
        );
    },

    handleSelect: function(eventKey, event) {
        this.handle(this, 'onSelect', [this.props.eventKey, eventKey, event]);
    }

});

function getClassName(that, props) {
    var includes = that.includes(props, Arrays, 'ms-List--');
    return that.className(props.className, 'ms-List', includes);
}

function getItems(that, props) {
    return React.Children.map(props.children, function(e, i) {
        return React.cloneElement(e, {eventKey: i});
    });
}

module.exports = List;
